==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Uncertainty/Algorithm/Simulation/DirectionalSampling/SamplingStrategyImplementation.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  SamplingStrategyImplementation.cxx
 *  @brief 
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu 26 jun 2008) $
 *  Id:      $Id: SamplingStrategyImplementation.cxx 862 2008-06-26 11:50:17Z dutka $
 */
#include "SamplingStrategyImplementation.hxx"
#include "Exception.hxx"
#include "DistFunc.hxx"

namespace OpenTURNS
{

  namespace Uncertainty 
  {

    namespace Algorithm
    {

      typedef Base::Common::NotYetImplementedException NotYetImplementedException;
      typedef Distribution::DistFunc                   DistFunc;

      /**
       * @class SamplingStrategyImplementation
       */

      CLASSNAMEINIT(SamplingStrategyImplementation);

      /* Constructor with parameters */
      SamplingStrategyImplementation::SamplingStrategyImplementation(const UnsignedLong dimension)
	: Base::Common::PersistentObject(),
	  dimension_(dimension)
      {
	// Nothing to do
      }

      /* Virtual constructor */
      SamplingStrategyImplementation * SamplingStrategyImplementation::clone() const
      {
	return new SamplingStrategyImplementation(*this);
      }

      /* Generate a set of directions */
      SamplingStrategyImplementation::NumericalSample SamplingStrategyImplementation::generate() const
      {
	throw NotYetImplementedException(HERE);
      }

      /* Generate a uniform random unit vector */
      SamplingStrategyImplementation::NumericalPoint SamplingStrategyImplementation::getUniformUnitVectorRealization(const UnsignedLong dimension) const
      {
	NumericalPoint direction(dimension);
	NumericalScalar norm(0.0);
	do
	  {
	    for (UnsignedLong i = 0; i < dimension; i++)
	      {
		direction[i] = DistFunc::rNormal();
	      }
	    norm = direction.norm();
	  }
	while (norm == 0.0);
	return (1.0 / norm) * direction;
      }

      /* Generate a uniform random unit vector */
      SamplingStrategyImplementation::NumericalPoint SamplingStrategyImplementation::getUniformUnitVectorRealization() const
      {
	return getUniformUnitVectorRealization(dimension_);
      }

      /* Dimension accessor */
      void SamplingStrategyImplementation::setDimension(const UnsignedLong dimension)
      {
	dimension_ = dimension;
      }

      UnsignedLong SamplingStrategyImplementation::getDimension() const
      {
	return dimension_;
      }

      /* String converter */
      String SamplingStrategyImplementation::str() const
      {
	OSS oss;
	oss << "class=" << SamplingStrategyImplementation::GetClassName()
	    << " dimension=" << dimension_;
	return oss;
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/src/Uncertainty/Algorithm/Simulation/DirectionalSampling/SamplingStrategyImplementation.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  SamplingStrategyImplementation.cxx
 *  @brief 
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: SamplingStrategyImplementation.cxx 1262 2009-05-28 12:47:53Z dutka $
 */
#include "SamplingStrategyImplementation.hxx"
#include "Exception.hxx"
#include "DistFunc.hxx"

namespace OpenTURNS
{

  namespace Uncertainty 
  {

    namespace Algorithm
    {

      typedef Base::Common::NotYetImplementedException NotYetImplementedException;
      typedef Distribution::DistFunc                   DistFunc;

      /**
       * @class SamplingStrategyImplementation
       */

      CLASSNAMEINIT(SamplingStrategyImplementation);

      /* Constructor with parameters */
      SamplingStrategyImplementation::SamplingStrategyImplementation(const UnsignedLong dimension)
	: Base::Common::PersistentObject(),
	  dimension_(dimension)
      {
	// Nothing to do
      }

      /* Virtual constructor */
      SamplingStrategyImplementation * SamplingStrategyImplementation::clone() const
      {
	return new SamplingStrategyImplementation(*this);
      }

      /* Generate a set of directions */
      SamplingStrategyImplementation::NumericalSample SamplingStrategyImplementation::generate() const
      {
	throw NotYetImplementedException(HERE);
      }

      /* Generate a uniform random unit vector */
      SamplingStrategyImplementation::NumericalPoint SamplingStrategyImplementation::getUniformUnitVectorRealization(const UnsignedLong dimension) const
      {
	NumericalPoint direction(dimension);
	NumericalScalar norm(0.0);
	do
	  {
	    for (UnsignedLong i = 0; i < dimension; i++)
	      {
		direction[i] = DistFunc::rNormal();
	      }
	    norm = direction.norm();
	  }
	while (norm == 0.0);
	return (1.0 / norm) * direction;
      }

      /* Generate a uniform random unit vector */
      SamplingStrategyImplementation::NumericalPoint SamplingStrategyImplementation::getUniformUnitVectorRealization() const
      {
	return getUniformUnitVectorRealization(dimension_);
      }

      /* Dimension accessor */
      void SamplingStrategyImplementation::setDimension(const UnsignedLong dimension)
      {
	dimension_ = dimension;
      }

      UnsignedLong SamplingStrategyImplementation::getDimension() const
      {
	return dimension_;
      }

      /* String converter */
      String SamplingStrategyImplementation::__repr__() const
      {
	OSS oss;
	oss << "class=" << SamplingStrategyImplementation::GetClassName()
	    << " dimension=" << dimension_;
	return oss;
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
